==> modin-0.12.1.tar.gz: modin-0.12.1/modin/core/execution/python/implementations/pandas_on_python/partitioning/partition_manager.py <==
# Licensed to Modin Development Team under one or more contributor license agreements.
# See the NOTICE file distributed with this work for additional information regarding
# copyright ownership.  The Modin Development Team licenses this file to you under the
# Apache License, Version 2.0 (the "License"); you may not use this file except in
# compliance with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software distributed under
# the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
# ANY KIND, either express or implied. See the License for the specific language
# governing permissions and limitations under the License.

"""Module houses class for managing partitions with pandas storage format and Python engine."""

from modin.core.dataframe.pandas.partitioning.partition_manager import (
    PandasDataframePartitionManager,
)
from .axis_partition import (
    PandasOnPythonDataframeColumnPartition,
    PandasOnPythonDataframeRowPartition,
)
from .partition import PandasOnPythonDataframePartition


class PandasOnPythonDataframePartitionManager(PandasDataframePartitionManager):
    """
    Class for managing partitions with pandas storage format and Python engine.

    Inherits all functionality from ``PandasDataframePartitionManager`` base class.
    """

    _partition_class = PandasOnPythonDataframePartition
    _column_partitions_class = PandasOnPythonDataframeColumnPartition
    _row_partition_class = PandasOnPythonDataframeRowPartition

==> modin-0.15.0.tar.gz: modin-0.15.0/modin/core/execution/python/implementations/pandas_on_python/partitioning/partition_manager.py <==
# Licensed to Modin Development Team under one or more contributor license agreements.
# See the NOTICE file distributed with this work for additional information regarding
# copyright ownership.  The Modin Development Team licenses this file to you under the
# Apache License, Version 2.0 (the "License"); you may not use this file except in
# compliance with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software distributed under
# the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
# ANY KIND, either express or implied. See the License for the specific language
# governing permissions and limitations under the License.

"""Module houses class for managing partitions with pandas storage format and Python engine."""

from modin.core.dataframe.pandas.partitioning.partition_manager import (
    PandasDataframePartitionManager,
)
from .virtual_partition import (
    PandasOnPythonDataframeColumnPartition,
    PandasOnPythonDataframeRowPartition,
)
from .partition import PandasOnPythonDataframePartition


class PandasOnPythonDataframePartitionManager(PandasDataframePartitionManager):
    """
    Class for managing partitions with pandas storage format and Python engine.

    Inherits all functionality from ``PandasDataframePartitionManager`` base class.
    """

    _partition_class = PandasOnPythonDataframePartition
    _column_partitions_class = PandasOnPythonDataframeColumnPartition
    _row_partition_class = PandasOnPythonDataframeRowPartition
